import axios from 'axios'
import { getToken } from 'utils/store'
import { routers } from 'router/index'
import { ElNotification } from 'element-plus'
import qs from 'qs'

const request = axios.create({
  baseURL: import.meta.env.PROD ? import.meta.env.VITE_BASE_API : '',
  timeout: import.meta.env.VITE_TIME_OUT
})

request.interceptors.request.use(config => {
  //  获取accessToken
  const accessToken = getToken()
  //  添加请求头信息，处理安全性问题
  if (accessToken) {
    config.headers.Authorization = 'Bearer ' + accessToken
  } else {
    config.headers.Authorization = 'Basic dnVlOnZ1ZQ=='
  }
  //  添加时间戳防止IE不刷新页面
  if (config.type != 'FORM') {
    if (config.method == 'post' || config.method == 'delete') {
      config.data = {
        ...config.data
      }
    } else if (config.method == 'get') {
      config.paramsSerializer = function (params) {
        return qs.stringify(params, { arrayFormat: 'repeat' })
      }
      config.params = {
        ...config.params,
        _t: Date.parse(new Date()) / 1000
      }
    }
  } else {
    let formData = ''
    Object.keys(config.data).forEach((key) => {
      formData += key + '=' + config.data[key] + '&'
    })
    config.data = formData
    config.headers.Accept = 'application/json'
    config.headers['Content-Type'] = 'application/x-www-form-urlencoded'
  }
  return config
}, error => {
  // 处理请求错误
  Promise.reject(error)
})

request.interceptors.response.use(
  response => {
    // 请求成功处理
    const res = response.data
    if (res.status == 401) {
      routers.push({
        path: '/'
      })
    }
    return res
  },
  error => {
    // 处理请求错误
    const response = error.response
    if (response != undefined && response.data && response.status == 200) {
      ElNotification({
        title: '请求出错',
        message: response.data.message,
        type: 'error'
      })
    } else {
      ElNotification({
        title: '错误的请求',
        type: 'error'
      })
    }
    // 弹出层
    return Promise.reject(error)
  }
)

export default request
